@@ -1,7 +1,9 @@
-__version__ = '0.3.8'
+__version__ = '0.5.0'
 __app_name__ = 'fudan-jwc-news'
 
 try:
+    # raise ImportError
+    raise
     from logging_utils_tddschn import get_logger
     logger, _ = get_logger(__app_name__)
 except:
